==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņas saturs',
	emailSubject: 'Ziņas tēma',
	id: 'ID',
	info: 'Hipersaites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Labot hipersaiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu norādi e-pasta adresi',
	noUrl: 'Lūdzu norādi hipersaiti',
	other: '<cits>',
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Hipersaite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toolbar: 'Ievietot/Labot hipersaiti',
	type: 'Hipersaites tips',
	unlink: 'Noņemt hipersaiti',
	upload: 'Augšupielādēt'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	download: 'Piespiedu ielāde',
	displayText: 'Attēlot tekstu',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņas saturs',
	emailSubject: 'Ziņas tēma',
	id: 'ID',
	info: 'Hipersaites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Labot hipersaiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu norādi e-pasta adresi',
	noUrl: 'Lūdzu norādi hipersaiti',
	noTel: 'Please type the phone number', // MISSING
	other: '<cits>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Hipersaite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ievietot/Labot hipersaiti',
	type: 'Hipersaites tips',
	unlink: 'Noņemt hipersaiti',
	upload: 'Augšupielādēt'
} );
